require 'spec_helper'

describe RightPublish::RepoManager do

  def is_registered?(name, key, type)
    @repo_types = RightPublish::RepoManager.repo_types
    @repo_types.should have_key(name)
    @repo_types[name].should equal(key)
    RightPublish::RepoManager.get_repository(key).should be_instance_of(type)
  end

  it "should provide a hash of known repo types" do
    RightPublish::RepoManager.repo_types.should be_instance_of(Hash)
  end

  it "returns nil for unknown repo types" do
    RightPublish::RepoManager.get_repository(:doesnotexist_repo).should be_equal(nil)
  end

  it "should know about the apt repository" do
    is_registered?('apt', :apt_repo, RightPublish::AptRepo)
  end

  it "should know about the gem repository" do
    is_registered?('gem', :gem_repo, RightPublish::GemRepo)
  end

  it "should know about the yum repository" do
    is_registered?('yum', :yum_repo, RightPublish::YumRepo)
  end

  context ".register_repo" do
    it "rejects repos without a REPO_KEY" do
      class MissingKey
      end
      expect { RightPublish::RepoManager.register_repo(MissingKey) }.to raise_error(NameError)
    end

    it "rejects repos whose key does not end in _repo" do
      class BadKey
        REPO_KEY = :bad_key
      end
      expect { RightPublish::RepoManager.register_repo(BadKey) }.to raise_error(TypeError)
    end

    it "rejects repos who do not provide options" do
      class NoOptions
        REPO_KEY = :nooptions_repo
      end
      expect { RightPublish::RepoManager.register_repo(NoOptions) }.to raise_error(NameError)
    end

    it "accpets repos who are properly defined" do
      class GoodRepo < RightPublish::Repo
        REPO_KEY = :good_repo
        REPO_OPTIONS = {}
      end
      RightPublish::RepoManager.register_repo(GoodRepo).should be_equal(nil)
      is_registered?('good', :good_repo, GoodRepo)
    end
  end

end
