require 'spec_helper'

describe RightPublish::StorageManager do

  def is_registered?(name, key)
    @storage_types = RightPublish::StorageManager.storage_types
    @storage_types.should have_key(name)
    @storage_types[name].should equal(key)
    RightPublish::StorageManager.get_storage(key)::STORAGE_KEY.should be_equal(key)
  end

  it "should provide a hash of known storage types" do
    RightPublish::StorageManager.storage_types.should be_instance_of(Hash)
  end

  it "returns nil for unknown storage types" do
    RightPublish::StorageManager.get_storage(:doesnotexist_storage).should be_equal(nil)
  end

  it "should know about the local storage" do
    is_registered?('local', :local_storage)
  end

  it "should know about the s3 storage" do
    is_registered?('s3', :s3_storage)
  end

  context ".register_storage" do
    it "rejects storage without a STORAGE_KEY" do
      class MissingKey
      end
      expect { RightPublish::StorageManager.register_storage(MissingKey) }.to raise_error(NameError)
    end

    it "rejects storage whose key does not end in _storage" do
      class BadKey
        STORAGE_KEY = :bad_key
      end
      expect { RightPublish::StorageManager.register_storage(BadKey) }.to raise_error(TypeError)
    end

    it "rejects storage who do not provide .get_directories" do
      class NoDirectories
        STORAGE_KEY = :nooptions_storage
      end
      expect { RightPublish::StorageManager.register_storage(NoDirectories) }.to raise_error(TypeError)
    end

    it "rejects storage who do not provide options" do
      class NoOptions
        STORAGE_KEY = :nooptions_storage
        def self.get_directories()
        end
      end
      expect { RightPublish::StorageManager.register_storage(NoOptions) }.to raise_error(NameError)
    end

    it "accpets storage who are properly defined" do
      class GoodStorage
        STORAGE_KEY = :good_storage
        STORAGE_OPTIONS = {}
        def self.get_directories()
        end
      end
      RightPublish::StorageManager.register_storage(GoodStorage).should be_equal(nil)
      is_registered?('good', :good_storage)
    end
  end

end
